Function BMSduplicateChunkMemory_call

pub unsafe extern "C" fn BMSduplicateChunkMemory_call(
    chkmem: *mut BMS_CHKMEM,
    source: *const c_void,
    size: usize,
    filename: *const c_char,
    line: c_int,
) -> *mut c_void
duplicates a given memory element by allocating a new element of the same chunk block and copying the data