Function BMSgarbagecollectBlockMemory_call

pub unsafe extern "C" fn BMSgarbagecollectBlockMemory_call(
    blkmem: *mut BMS_BLKMEM,
)
calls garbage collection of block memory, frees chunks without allocated memory elements, and frees chunk blocks without any chunks