Function SCIPaddClique

pub unsafe extern "C" fn SCIPaddClique(
    scip: *mut SCIP,
    vars: *mut *mut SCIP_VAR,
    values: *mut c_uint,
    nvars: c_int,
    isequation: c_uint,
    infeasible: *mut c_uint,
    nbdchgs: *mut c_int,
) -> SCIP_RETCODE
adds a clique information to SCIP, stating that at most one of the given binary variables can be set to 1; if a variable appears twice in the same clique, the corresponding implications are performed

@return \ref SCIP_OKAY is returned if everything worked. Otherwise a suitable error code is passed. See \ref SCIP_Retcode “SCIP_RETCODE” for a complete list of error codes.

@pre This method can be called if @p scip is in one of the following stages: - \ref SCIP_STAGE_TRANSFORMED - \ref SCIP_STAGE_PRESOLVING - \ref SCIP_STAGE_PRESOLVED - \ref SCIP_STAGE_SOLVING