Function SCIPaddOrigObjoffset

pub unsafe extern "C" fn SCIPaddOrigObjoffset(
    scip: *mut SCIP,
    addval: f64,
) -> SCIP_RETCODE
adds offset of objective function to original problem and to all existing solution in original space

@return \ref SCIP_OKAY is returned if everything worked. otherwise a suitable error code is passed. see \ref SCIP_Retcode “SCIP_RETCODE” for a complete list of error codes.

@pre This method can be called if @p scip is in one of the following stages: - \ref SCIP_STAGE_PROBLEM