Function SCIPanalyzeDeductionsProbing

pub unsafe extern "C" fn SCIPanalyzeDeductionsProbing(
    scip: *mut SCIP,
    probingvar: *mut SCIP_VAR,
    leftub: f64,
    rightlb: f64,
    nvars: c_int,
    vars: *mut *mut SCIP_VAR,
    leftimpllbs: *mut f64,
    leftimplubs: *mut f64,
    leftproplbs: *mut f64,
    leftpropubs: *mut f64,
    rightimpllbs: *mut f64,
    rightimplubs: *mut f64,
    rightproplbs: *mut f64,
    rightpropubs: *mut f64,
    nfixedvars: *mut c_int,
    naggrvars: *mut c_int,
    nimplications: *mut c_int,
    nchgbds: *mut c_int,
    cutoff: *mut c_uint,
) -> SCIP_RETCODE
analyses boundchanges resulting from probing on a variable and performs deduced fixations, aggregations, and domain tightenings

Given a variable probingvar with domain [l,u] and bound tightening results from reducing the domain once to [l,leftub] and once to [rightlb,u], the method computes and applies resulting variable fixations, aggregations, implications, and bound changes. Variable probingvar does not need to be binary. The whole domain of probingvar need to be covered by the left and right branches, i.e., we assume leftub >= rightlb for continuous variables or floor(leftub) >= ceil(rightlb)-1 for discrete variables. Bounds after applying implications and cliques do not need to be provided, but if they are omitted and probingvar is a binary variable, then already existing implications may be added.