Function SCIPbdchginfoIsTighter

pub unsafe extern "C" fn SCIPbdchginfoIsTighter(
    bdchginfo1: *mut SCIP_BDCHGINFO,
    bdchginfo2: *mut SCIP_BDCHGINFO,
) -> c_uint
for two bound change informations belonging to the same variable and bound, returns whether the first bound change has a tighter new bound as the second bound change