pub unsafe extern "C" fn SCIPbendersSetSubproblemObjval(
benders: *mut SCIP_BENDERS,
probnumber: c_int,
objval: f64,
)Expand description
stores the objective function value of the subproblem for use in cut generation
pub unsafe extern "C" fn SCIPbendersSetSubproblemObjval(
benders: *mut SCIP_BENDERS,
probnumber: c_int,
objval: f64,
)stores the objective function value of the subproblem for use in cut generation