pub unsafe extern "C" fn SCIPbendersSubproblemIsConvex(
benders: *mut SCIP_BENDERS,
probnumber: c_int,
) -> c_uintExpand description
returns whether the subproblem is convex
This means that the dual solution can be used to generate cuts.
pub unsafe extern "C" fn SCIPbendersSubproblemIsConvex(
benders: *mut SCIP_BENDERS,
probnumber: c_int,
) -> c_uintreturns whether the subproblem is convex
This means that the dual solution can be used to generate cuts.