pub unsafe extern "C" fn SCIPboundchgGetNewbound(
boundchg: *mut SCIP_BOUNDCHG,
) -> f64Expand description
returns the new value of the bound in the bound change data
pub unsafe extern "C" fn SCIPboundchgGetNewbound(
boundchg: *mut SCIP_BOUNDCHG,
) -> f64returns the new value of the bound in the bound change data