Function SCIPboundchgIsRedundant

pub unsafe extern "C" fn SCIPboundchgIsRedundant(
    boundchg: *mut SCIP_BOUNDCHG,
) -> c_uint
returns whether the bound change is redundant due to a more global bound that is at least as strong