pub unsafe extern "C" fn SCIPcalcChildEstimate(
scip: *mut SCIP,
var: *mut SCIP_VAR,
targetvalue: f64,
) -> f64Expand description
calculates an estimate for the objective of the best feasible solution contained in the subtree after applying the given branching; this estimate can be given to the SCIPcreateChild() call
@return the estimate for the objective of the best feasible solution contained in the subtree after applying the given branching.
@pre This method can be called if @p scip is in one of the following stages: - \ref SCIP_STAGE_SOLVING
See \ref SCIP_Stage “SCIP_STAGE” for a complete list of all possible solving stages.