Function SCIPcalcIntegralScalar

pub unsafe extern "C" fn SCIPcalcIntegralScalar(
    vals: *mut f64,
    nvals: c_int,
    mindelta: f64,
    maxdelta: f64,
    maxdnom: c_longlong,
    maxscale: f64,
    intscalar: *mut f64,
    success: *mut c_uint,
) -> SCIP_RETCODE
tries to find a value, such that all given values, if scaled with this value become integral in relative allowed difference in between mindelta and maxdelta