Function SCIPcalcRootNewton

pub unsafe extern "C" fn SCIPcalcRootNewton(
    function: Option<unsafe extern "C" fn(point: f64, params: *mut f64, nparams: c_int) -> f64>,
    derivative: Option<unsafe extern "C" fn(point: f64, params: *mut f64, nparams: c_int) -> f64>,
    params: *mut f64,
    nparams: c_int,
    x: f64,
    eps: f64,
    k: c_int,
) -> f64
Performs the Newton Procedure from a given starting point to compute a root of the given function with specified precision and maximum number of iterations. If the procedure fails, SCIP_INVALID is returned.