Function SCIPchgAndConsRemovableFlagWhenUpgr

pub unsafe extern "C" fn SCIPchgAndConsRemovableFlagWhenUpgr(
    scip: *mut SCIP,
    cons: *mut SCIP_CONS,
    flag: c_uint,
) -> SCIP_RETCODE
when ‘upgrading’ the given AND-constraint, should the removable flag for the upgraded constraint be set to FALSE, even if the removable flag of this AND-constraint is set to TRUE?