pub unsafe extern "C" fn SCIPcomputeLPRelIntPoint(
scip: *mut SCIP,
relaxrows: c_uint,
inclobjcutoff: c_uint,
timelimit: f64,
iterlimit: c_int,
point: *mut *mut SCIP_SOL,
) -> SCIP_RETCODEExpand description
compute relative interior point to current LP @see SCIPlpComputeRelIntPoint
@return \ref SCIP_OKAY is returned if everything worked. Otherwise a suitable error code is passed. See \ref SCIP_Retcode “SCIP_RETCODE” for a complete list of error codes.
@pre This method can be called if @p scip is in one of the following stages: - \ref SCIP_STAGE_TRANSFORMED - \ref SCIP_STAGE_INITPRESOLVE - \ref SCIP_STAGE_PRESOLVING - \ref SCIP_STAGE_EXITPRESOLVE - \ref SCIP_STAGE_PRESOLVED - \ref SCIP_STAGE_SOLVING - \ref SCIP_STAGE_SOLVED
See \ref SCIP_Stage “SCIP_STAGE” for a complete list of all possible solving stages.