pub unsafe extern "C" fn SCIPconsBendersEnforceSolution(
scip: *mut SCIP,
sol: *mut SCIP_SOL,
conshdlr: *mut SCIP_CONSHDLR,
result: *mut SCIP_RESULT,
type_: SCIP_BENDERSENFOTYPE,
checkint: c_uint,
) -> SCIP_RETCODEExpand description
enforces Benders’ constraints for given solution
This method is called from cons_benderslp and cons_benders. If the method is called from cons_benderslp, then the solutions are not guaranteed to be integer feasible. This is because the default priority is set greater than the integer constraint handler. If this method is called from cons_benders, then, because the default enforcement priority is set less than that of the integer constraint handler, then it can be assumed that the solutions are integer feasible.
The checkint flag indicates whether integer feasibility can be assumed. If it is not assumed, i.e. checkint == FALSE, then only the convex relaxations of the subproblems are solved. If integer feasibility is assumed, i.e. checkint == TRUE, then the convex relaxations and the full CIP are solved to generate Benders’ cuts and check solution feasibility.