pub unsafe extern "C" fn SCIPconshdlrGetPropTiming(
conshdlr: *mut SCIP_CONSHDLR,
) -> SCIP_PROPTIMINGExpand description
returns the timing mask of the propagation method of the constraint handler
pub unsafe extern "C" fn SCIPconshdlrGetPropTiming(
conshdlr: *mut SCIP_CONSHDLR,
) -> SCIP_PROPTIMINGreturns the timing mask of the propagation method of the constraint handler