pub unsafe extern "C" fn SCIPcorGetNConsNames(
reader: *mut SCIP_READER,
) -> c_intExpand description
returns the number of constraint names in the COR problem
pub unsafe extern "C" fn SCIPcorGetNConsNames(
reader: *mut SCIP_READER,
) -> c_intreturns the number of constraint names in the COR problem