pub unsafe extern "C" fn SCIPcutpoolGetMaxNCuts(
cutpool: *mut SCIP_CUTPOOL,
) -> c_longlongExpand description
get maximum number of cuts that were stored in the cut pool at the same time
pub unsafe extern "C" fn SCIPcutpoolGetMaxNCuts(
cutpool: *mut SCIP_CUTPOOL,
) -> c_longlongget maximum number of cuts that were stored in the cut pool at the same time