pub unsafe extern "C" fn SCIPcutpoolGetNCutsAdded(
cutpool: *mut SCIP_CUTPOOL,
) -> c_longlongExpand description
get total number of cuts that were added from the cut pool to sepastore
pub unsafe extern "C" fn SCIPcutpoolGetNCutsAdded(
cutpool: *mut SCIP_CUTPOOL,
) -> c_longlongget total number of cuts that were added from the cut pool to sepastore