pub unsafe extern "C" fn SCIPdivesetGetNSolutionCalls(
diveset: *mut SCIP_DIVESET,
divecontext: SCIP_DIVECONTEXT,
) -> c_intExpand description
get the number of calls successfully terminated at a feasible leaf node
pub unsafe extern "C" fn SCIPdivesetGetNSolutionCalls(
diveset: *mut SCIP_DIVESET,
divecontext: SCIP_DIVECONTEXT,
) -> c_intget the number of calls successfully terminated at a feasible leaf node