Function SCIPendProbing

pub unsafe extern "C" fn SCIPendProbing(
    scip: *mut SCIP,
) -> SCIP_RETCODE
quits probing and resets bounds and constraints to the focus node’s environment

@return \ref SCIP_OKAY is returned if everything worked. Otherwise a suitable error code is passed. See \ref SCIP_Retcode “SCIP_RETCODE” for a complete list of error codes.

@pre This method can be called if @p scip is in one of the following stages: - \ref SCIP_STAGE_PRESOLVING - \ref SCIP_STAGE_SOLVING