pub unsafe extern "C" fn SCIPeventGetNewImpltype(
event: *mut SCIP_EVENT,
) -> SCIP_IMPLINTTYPEExpand description
gets new implied integral type for an implied integral type change event
pub unsafe extern "C" fn SCIPeventGetNewImpltype(
event: *mut SCIP_EVENT,
) -> SCIP_IMPLINTTYPEgets new implied integral type for an implied integral type change event