Function SCIPexprGetQuadraticQuadTerm

pub unsafe extern "C" fn SCIPexprGetQuadraticQuadTerm(
    quadexpr: *mut SCIP_EXPR,
    termidx: c_int,
    expr: *mut *mut SCIP_EXPR,
    lincoef: *mut f64,
    sqrcoef: *mut f64,
    nadjbilin: *mut c_int,
    adjbilin: *mut *mut c_int,
    sqrexpr: *mut *mut SCIP_EXPR,
)
gives the data of a quadratic expression term

For a term \f$a \cdot \text{expr}^2 + b \cdot \text{expr} + \sum_i (c_i \cdot \text{expr} \cdot \text{otherexpr}_i)\f$, returns expr, \f$a\f$, \f$b\f$, the number of summands, and indices of bilinear terms in the quadratic expressions bilinexprterms.

This function returns pointers to internal data in adjbilin. The user must not change this data.