pub unsafe extern "C" fn SCIPexprcurvNegate(
curvature: SCIP_EXPRCURV,
) -> SCIP_EXPRCURVExpand description
gives the curvature for the negation of a function with given curvature
pub unsafe extern "C" fn SCIPexprcurvNegate(
curvature: SCIP_EXPRCURV,
) -> SCIP_EXPRCURVgives the curvature for the negation of a function with given curvature