pub unsafe extern "C" fn SCIPexprhdlrIncrementNBranchings(
exprhdlr: *mut SCIP_EXPRHDLR,
)Expand description
increments the branching candidates count of an expression handler
pub unsafe extern "C" fn SCIPexprhdlrIncrementNBranchings(
exprhdlr: *mut SCIP_EXPRHDLR,
)increments the branching candidates count of an expression handler