pub unsafe extern "C" fn SCIPexprhdlrIncrementNDomainReductions(
exprhdlr: *mut SCIP_EXPRHDLR,
nreductions: c_int,
)Expand description
increments the domain reductions count of an expression handler
pub unsafe extern "C" fn SCIPexprhdlrIncrementNDomainReductions(
exprhdlr: *mut SCIP_EXPRHDLR,
nreductions: c_int,
)increments the domain reductions count of an expression handler