Function SCIPfreeBendersSubproblem

pub unsafe extern "C" fn SCIPfreeBendersSubproblem(
    scip: *mut SCIP,
    benders: *mut SCIP_BENDERS,
    probnumber: c_int,
) -> SCIP_RETCODE
frees the subproblem after calling the solve subproblem method

This will either call the user defined free subproblem callback for Benders’ decomposition or the default freeing methods. In the default case, if the subproblem is an LP, then SCIPendProbing is called. If the subproblem is a MIP, then SCIPfreeTransform is called.

@return \ref SCIP_OKAY is returned if everything worked. Otherwise a suitable error code is passed. See \ref SCIP_Retcode “SCIP_RETCODE” for a complete list of error codes.

@pre This method can be called if SCIP is in one of the following stages: - \ref SCIP_STAGE_INITPRESOLVE - \ref SCIP_STAGE_PRESOLVING - \ref SCIP_STAGE_EXITPRESOLVE - \ref SCIP_STAGE_PRESOLVED - \ref SCIP_STAGE_INITSOLVE - \ref SCIP_STAGE_SOLVING - \ref SCIP_STAGE_SOLVED - \ref SCIP_STAGE_EXITSOLVE - \ref SCIP_STAGE_FREETRANS