Function SCIPgetAvgCutoffsCurrentRun

pub unsafe extern "C" fn SCIPgetAvgCutoffsCurrentRun(
    scip: *mut SCIP,
    dir: SCIP_BRANCHDIR,
) -> f64
returns the average number of cutoffs found after branching in given direction over all variables, only using the cutoff information of the current run

@return the average number of cutoffs found after branching in given direction over all variables, only using the cutoff information of the current run

@pre This method can be called if SCIP is in one of the following stages: - \ref SCIP_STAGE_SOLVING - \ref SCIP_STAGE_SOLVED