Function SCIPgetCutEfficacy

pub unsafe extern "C" fn SCIPgetCutEfficacy(
    scip: *mut SCIP,
    sol: *mut SCIP_SOL,
    cut: *mut SCIP_ROW,
) -> f64
returns efficacy of the cut with respect to the given primal solution or the current LP solution: e = -feasibility/norm

@return the efficacy of the cut with respect to the given primal solution or the current LP solution: e = -feasibility/norm

@pre This method can be called if @p scip is in one of the following stages: - \ref SCIP_STAGE_SOLVING