Function SCIPgetLastDivenode

pub unsafe extern "C" fn SCIPgetLastDivenode(
    scip: *mut SCIP,
) -> c_longlong
returns the number of the node in the current branch and bound run, where the last LP was solved in diving or probing mode

@return the number of the node in the current branch and bound run, where the last LP was solved in diving or probing mode.

@pre This method can be called if @p scip is in one of the following stages: - \ref SCIP_STAGE_TRANSFORMING - \ref SCIP_STAGE_TRANSFORMED - \ref SCIP_STAGE_INITPRESOLVE - \ref SCIP_STAGE_PRESOLVING - \ref SCIP_STAGE_EXITPRESOLVE - \ref SCIP_STAGE_PRESOLVED - \ref SCIP_STAGE_INITSOLVE - \ref SCIP_STAGE_SOLVING - \ref SCIP_STAGE_SOLVED - \ref SCIP_STAGE_EXITSOLVE - \ref SCIP_STAGE_FREETRANS

See \ref SCIP_Stage “SCIP_STAGE” for a complete list of all possible solving stages.