pub unsafe extern "C" fn SCIPgetNRootFirstLPIterations(
scip: *mut SCIP,
) -> c_longlongExpand description
gets total number of iterations used in primal and dual simplex and barrier algorithm for the first LP at the root node
@return the total number of iterations used in primal and dual simplex and barrier algorithm for the first root LP
@pre This method can be called if SCIP is in one of the following stages: - \ref SCIP_STAGE_PRESOLVED - \ref SCIP_STAGE_SOLVING - \ref SCIP_STAGE_SOLVED