Function SCIPgetSolVarsData

pub unsafe extern "C" fn SCIPgetSolVarsData(
    scip: *mut SCIP,
    sol: *mut SCIP_SOL,
    vars: *mut *mut *mut SCIP_VAR,
    nvars: *mut c_int,
    nbinvars: *mut c_int,
    nintvars: *mut c_int,
    nimplvars: *mut c_int,
    ncontvars: *mut c_int,
) -> SCIP_RETCODE
gets variables of the original or transformed problem along with the numbers of different variable types; the returned problem space (original or transformed) corresponds to the given solution; data may become invalid after calls to SCIPchgVarType(), SCIPfixVar(), SCIPaggregateVars(), and SCIPmultiaggregateVar()

@return \ref SCIP_OKAY is returned if everything worked. Otherwise a suitable error code is passed. See \ref SCIP_Retcode “SCIP_RETCODE” for a complete list of error codes.

@pre This method can be called if @p scip is in one of the following stages: - \ref SCIP_STAGE_PROBLEM - \ref SCIP_STAGE_TRANSFORMED - \ref SCIP_STAGE_INITPRESOLVE - \ref SCIP_STAGE_PRESOLVING - \ref SCIP_STAGE_EXITPRESOLVE - \ref SCIP_STAGE_PRESOLVED - \ref SCIP_STAGE_INITSOLVE - \ref SCIP_STAGE_SOLVING - \ref SCIP_STAGE_SOLVED