pub unsafe extern "C" fn SCIPgetVarStrongbranchInt(
scip: *mut SCIP,
var: *mut SCIP_VAR,
itlim: c_int,
idempotent: c_uint,
down: *mut f64,
up: *mut f64,
downvalid: *mut c_uint,
upvalid: *mut c_uint,
downinf: *mut c_uint,
upinf: *mut c_uint,
downconflict: *mut c_uint,
upconflict: *mut c_uint,
lperror: *mut c_uint,
) -> SCIP_RETCODEExpand description
gets strong branching information on column variable x with integral LP solution value (val); that is, the down branch is (val -1.0) and the up brach ins (val +1.0)
@return \ref SCIP_OKAY is returned if everything worked. Otherwise a suitable error code is passed. See \ref SCIP_Retcode “SCIP_RETCODE” for a complete list of error codes.
@pre This method can be called if @p scip is in one of the following stages: - \ref SCIP_STAGE_PRESOLVED - \ref SCIP_STAGE_SOLVING
@note If the integral LP solution value is the lower or upper bound of the variable, the corresponding branch will be marked as infeasible. That is, the valid pointer and the infeasible pointer are set to TRUE.