pub unsafe extern "C" fn SCIPhashsetGetNElements(
hashset: *mut SCIP_HASHSET,
) -> c_intExpand description
gives the number of elements in a hash set
pub unsafe extern "C" fn SCIPhashsetGetNElements(
hashset: *mut SCIP_HASHSET,
) -> c_intgives the number of elements in a hash set