Function SCIPhashtableClear

pub unsafe extern "C" fn SCIPhashtableClear(
    hashtable: *mut SCIP_HASHTABLE,
)
removes all elements of the hash table

@note From a performance point of view you should not fill and clear a hash table too often since the clearing can be expensive. Clearing is done by looping over all buckets and removing the hash table lists one-by-one.

@deprecated Please use SCIPhashtableRemoveAll()