pub unsafe extern "C" fn SCIPincludeHeurObjpscostdiving(
scip: *mut SCIP,
) -> SCIP_RETCODEExpand description
creates the objpscostdiving heuristic and includes it in SCIP
@ingroup PrimalHeuristicIncludes
pub unsafe extern "C" fn SCIPincludeHeurObjpscostdiving(
scip: *mut SCIP,
) -> SCIP_RETCODEcreates the objpscostdiving heuristic and includes it in SCIP
@ingroup PrimalHeuristicIncludes