Function SCIPisConflictVarUsed

pub unsafe extern "C" fn SCIPisConflictVarUsed(
    scip: *mut SCIP,
    var: *mut SCIP_VAR,
    boundtype: SCIP_BOUNDTYPE,
    bdchgidx: *mut SCIP_BDCHGIDX,
    used: *mut c_uint,
) -> SCIP_RETCODE
checks if the given variable is already part of the current conflict set or queued for resolving with the same or even stronger bound

@return \ref SCIP_OKAY is returned if everything worked. Otherwise a suitable error code is passed. See \ref SCIP_Retcode “SCIP_RETCODE” for a complete list of error codes.

@pre This method can be called if SCIP is in one of the following stages: - \ref SCIP_STAGE_PRESOLVING - \ref SCIP_STAGE_SOLVING

@note SCIP stage does not get changed