Function SCIPisObjIntegral

pub unsafe extern "C" fn SCIPisObjIntegral(scip: *mut SCIP) -> c_uint
returns whether the objective value is known to be integral in every feasible solution

@return TRUE, if objective value is known to be always integral, otherwise FALSE

@pre This method can be called if @p scip is in one of the following stages: - \ref SCIP_STAGE_PROBLEM - \ref SCIP_STAGE_TRANSFORMING - \ref SCIP_STAGE_INITPRESOLVE - \ref SCIP_STAGE_PRESOLVING - \ref SCIP_STAGE_EXITPRESOLVE - \ref SCIP_STAGE_PRESOLVED - \ref SCIP_STAGE_SOLVING

@note If no pricing is performed, SCIP automatically detects whether the objective function is integral or can be scaled to be integral, helping to improve performance. This function returns the result. Otherwise SCIPsetObjIntegral() can be used to inform SCIP. However, in any case, the user has to make sure that no variable is added during the solving process that destroys this property.