pub unsafe extern "C" fn SCIPlpExactUpdateVarColumn(
lpexact: *mut SCIP_LPEXACT,
set: *mut SCIP_SET,
var: *mut SCIP_VAR,
) -> SCIP_RETCODEExpand description
informs LP, that given formerly loose problem variable is now a column variable
pub unsafe extern "C" fn SCIPlpExactUpdateVarColumn(
lpexact: *mut SCIP_LPEXACT,
set: *mut SCIP_SET,
var: *mut SCIP_VAR,
) -> SCIP_RETCODEinforms LP, that given formerly loose problem variable is now a column variable