SCIPlpSetRootLPIsRelax

Function SCIPlpSetRootLPIsRelax 

pub unsafe extern "C" fn SCIPlpSetRootLPIsRelax(
    lp: *mut SCIP_LP,
    isrelax: c_uint,
)
sets whether the root LP is a relaxation of the problem and its optimal objective value is a global lower bound