Function SCIPlpiAddRows

pub unsafe extern "C" fn SCIPlpiAddRows(
    lpi: *mut SCIP_LPI,
    nrows: c_int,
    lhs: *const f64,
    rhs: *const f64,
    rownames: *mut *mut c_char,
    nnonz: c_int,
    beg: *const c_int,
    ind: *const c_int,
    val: *const f64,
) -> SCIP_RETCODE
adds rows to the LP

@note ind array is not checked for duplicates, problems may appear if indices are added more than once