pub unsafe extern "C" fn SCIPlpiGetBInvACol(
lpi: *mut SCIP_LPI,
c: c_int,
coef: *mut f64,
inds: *mut c_int,
ninds: *mut c_int,
) -> SCIP_RETCODEExpand description
get column of inverse basis matrix times constraint matrix B^-1 * A
@note The LP interface defines slack variables to have coefficient +1. This means that if, internally, the LP solver uses a -1 coefficient, then rows associated with slacks variables whose coefficient is -1, should be negated; see also the explanation in lpi.h.