Function SCIPlpiGetRows

pub unsafe extern "C" fn SCIPlpiGetRows(
    lpi: *mut SCIP_LPI,
    firstrow: c_int,
    lastrow: c_int,
    lhs: *mut f64,
    rhs: *mut f64,
    nnonz: *mut c_int,
    beg: *mut c_int,
    ind: *mut c_int,
    val: *mut f64,
) -> SCIP_RETCODE
gets rows from LP problem object; the arrays have to be large enough to store all values. Either both, lhs and rhs, have to be NULL, or both have to be non-NULL, either nnonz, beg, ind, and val have to be NULL, or all of them have to be non-NULL.