Function SCIPlpiGetSol

pub unsafe extern "C" fn SCIPlpiGetSol(
    lpi: *mut SCIP_LPI,
    objval: *mut f64,
    primsol: *mut f64,
    dualsol: *mut f64,
    activity: *mut f64,
    redcost: *mut f64,
) -> SCIP_RETCODE
gets primal and dual solution vectors for feasible LPs

Before calling this function, the caller must ensure that the LP has been solved to optimality, i.e., that SCIPlpiIsOptimal() returns true.