pub unsafe extern "C" fn SCIPmessageVFPrintWarning(
messagehdlr: *mut SCIP_MESSAGEHDLR,
formatstr: *const c_char,
ap: *mut __va_list_tag,
)Expand description
prints a warning message into a file, acting like the vfprintf() command
pub unsafe extern "C" fn SCIPmessageVFPrintWarning(
messagehdlr: *mut SCIP_MESSAGEHDLR,
formatstr: *const c_char,
ap: *mut __va_list_tag,
)prints a warning message into a file, acting like the vfprintf() command