pub unsafe extern "C" fn SCIPnlhdlrHasIntEval(
nlhdlr: *mut SCIP_NLHDLR,
) -> c_uintExpand description
returns whether nonlinear handler implements the interval evaluation callback
pub unsafe extern "C" fn SCIPnlhdlrHasIntEval(
nlhdlr: *mut SCIP_NLHDLR,
) -> c_uintreturns whether nonlinear handler implements the interval evaluation callback