pub unsafe extern "C" fn SCIPnlrowGetLhs(
nlrow: *mut SCIP_NLROW,
) -> f64Expand description
returns the left hand side of a nonlinear row
pub unsafe extern "C" fn SCIPnlrowGetLhs(
nlrow: *mut SCIP_NLROW,
) -> f64returns the left hand side of a nonlinear row