SCIPpermuteProb

Function SCIPpermuteProb 

pub unsafe extern "C" fn SCIPpermuteProb(
    scip: *mut SCIP,
    randseed: c_uint,
    permuteconss: c_uint,
    permutebinvars: c_uint,
    permuteintvars: c_uint,
    permutebinimplvars: c_uint,
    permuteintimplvars: c_uint,
    permutecontimplvars: c_uint,
    permutecontvars: c_uint,
) -> SCIP_RETCODE
permutes parts of the problem data structure

@return \ref SCIP_OKAY is returned if everything worked. otherwise a suitable error code is passed. see \ref SCIP_Retcode “SCIP_RETCODE” for a complete list of error codes.

@pre This method can be called if @p scip is in one of the following stages: - \ref SCIP_STAGE_PROBLEM - \ref SCIP_STAGE_TRANSFORMED

@todo This need to be changed to use the new random number generator implemented in random.c