pub unsafe extern "C" fn SCIPprintCons(
scip: *mut SCIP,
cons: *mut SCIP_CONS,
file: *mut FILE,
) -> SCIP_RETCODEExpand description
outputs constraint information to file stream via the message handler system
@return \ref SCIP_OKAY is returned if everything worked. Otherwise a suitable error code is passed. See \ref SCIP_Retcode “SCIP_RETCODE” for a complete list of error codes.
@pre This method can be called if @p scip is in one of the following stages: - \ref SCIP_STAGE_PROBLEM - \ref SCIP_STAGE_TRANSFORMING - \ref SCIP_STAGE_TRANSFORMED - \ref SCIP_STAGE_INITPRESOLVE - \ref SCIP_STAGE_PRESOLVING - \ref SCIP_STAGE_EXITPRESOLVE - \ref SCIP_STAGE_PRESOLVED - \ref SCIP_STAGE_INITSOLVE - \ref SCIP_STAGE_SOLVING - \ref SCIP_STAGE_SOLVED - \ref SCIP_STAGE_EXITSOLVE - \ref SCIP_STAGE_FREETRANS
@note If the message handler is set to a NULL pointer nothing will be printed. @note The file stream will not be flushed directly, this can be achieved by calling SCIPinfoMessage() printing a newline character.