Function SCIPprintStage

pub unsafe extern "C" fn SCIPprintStage(
    scip: *mut SCIP,
    file: *mut FILE,
) -> SCIP_RETCODE
outputs SCIP stage and solution status if applicable via the message handler

@note If the message handler is set to a NULL pointer nothing will be printed

@note If limits have been changed between the solution and the call to this function, the status is recomputed and thus may to correspond to the original status.

@return \ref SCIP_OKAY is returned if everything worked. Otherwise a suitable error code is passed. See \ref SCIP_Retcode “SCIP_RETCODE” for a complete list of error codes.

See \ref SCIP_Stage “SCIP_STAGE” for a complete list of all possible solving stages.