pub unsafe extern "C" fn SCIPreadSto(
scip: *mut SCIP,
filename: *const c_char,
result: *mut SCIP_RESULT,
) -> SCIP_RETCODEExpand description
reads the stochastic information for a stochastic program that is in SMPS format
pub unsafe extern "C" fn SCIPreadSto(
scip: *mut SCIP,
filename: *const c_char,
result: *mut SCIP_RESULT,
) -> SCIP_RETCODEreads the stochastic information for a stochastic program that is in SMPS format