pub unsafe extern "C" fn SCIPrelaxGetNImprovedLowerbound(
relax: *mut SCIP_RELAX,
) -> c_longlongExpand description
gets the total number of times the relaxation handler improved a node’s lower bound
pub unsafe extern "C" fn SCIPrelaxGetNImprovedLowerbound(
relax: *mut SCIP_RELAX,
) -> c_longlonggets the total number of times the relaxation handler improved a node’s lower bound