pub unsafe extern "C" fn SCIPremoveInefficaciousCuts(
scip: *mut SCIP,
) -> SCIP_RETCODEExpand description
removes cuts that are inefficacious w.r.t. the current LP solution from separation storage without adding the cuts to the LP
@return \ref SCIP_OKAY is returned if everything worked. Otherwise a suitable error code is passed. See \ref SCIP_Retcode “SCIP_RETCODE” for a complete list of error codes.
@pre This method can be called if @p scip is in one of the following stages: - \ref SCIP_STAGE_SOLVING