pub unsafe extern "C" fn SCIPsepaGetNCutsAddedDirect(
sepa: *mut SCIP_SEPA,
) -> c_longlongExpand description
gets the number of cutting planes from the separator added directly to the sepastore
pub unsafe extern "C" fn SCIPsepaGetNCutsAddedDirect(
sepa: *mut SCIP_SEPA,
) -> c_longlonggets the number of cutting planes from the separator added directly to the sepastore