pub unsafe extern "C" fn SCIPsepaGetNCutsAppliedDirect(
sepa: *mut SCIP_SEPA,
) -> c_longlongExpand description
gets the total number of cutting planes from the separator applied directly to the LP
pub unsafe extern "C" fn SCIPsepaGetNCutsAppliedDirect(
sepa: *mut SCIP_SEPA,
) -> c_longlonggets the total number of cutting planes from the separator applied directly to the LP