pub unsafe extern "C" fn SCIPsetNodeselMemsavePriority(
scip: *mut SCIP,
nodesel: *mut SCIP_NODESEL,
priority: c_int,
) -> SCIP_RETCODEExpand description
sets the priority of a node selector in memory saving mode
pub unsafe extern "C" fn SCIPsetNodeselMemsavePriority(
scip: *mut SCIP,
nodesel: *mut SCIP_NODESEL,
priority: c_int,
) -> SCIP_RETCODEsets the priority of a node selector in memory saving mode