pub unsafe extern "C" fn SCIPsetSetHeuristics(
set: *mut SCIP_SET,
messagehdlr: *mut SCIP_MESSAGEHDLR,
paramsetting: SCIP_PARAMSETTING,
quiet: c_uint,
) -> SCIP_RETCODEExpand description
sets heuristic parameters values to
- SCIP_PARAMSETTING_DEFAULT which are the default values of all heuristic parameters
- SCIP_PARAMSETTING_FAST such that the time spend for heuristic is decreased
- SCIP_PARAMSETTING_AGGRESSIVE such that the heuristic are called more aggregative
- SCIP_PARAMSETTING_OFF which turn off all heuristics