pub unsafe extern "C" fn SCIPsolSetHeur(
sol: *mut SCIP_SOL,
heur: *mut SCIP_HEUR,
)Expand description
informs the solution that it now belongs to the given primal heuristic. For convenience and backwards compatibility, the method accepts NULL as input for \p heur, in which case the solution type is set to SCIP_SOLTYPE_LPRELAX.
@note Relaxation handlers should use SCIPsolSetRelax() instead.