Function SCIPupdateCutoffbound

pub unsafe extern "C" fn SCIPupdateCutoffbound(
    scip: *mut SCIP,
    cutoffbound: f64,
) -> SCIP_RETCODE
updates the cutoff bound

@return \ref SCIP_OKAY is returned if everything worked. Otherwise a suitable error code is passed. See \ref SCIP_Retcode “SCIP_RETCODE” for a complete list of error codes.

@note using this method in the solving stage can lead to an erroneous SCIP solving status; in particular, if a solution not respecting the cutoff bound was found before installing a cutoff bound which renders the remaining problem infeasible, this solution may be reported as optimal

@pre This method can be called if SCIP is in one of the following stages: - \ref SCIP_STAGE_TRANSFORMED - \ref SCIP_STAGE_PRESOLVING - \ref SCIP_STAGE_PRESOLVED - \ref SCIP_STAGE_INITSOLVE - \ref SCIP_STAGE_SOLVING

@note the given cutoff bound has to better or equal to known one (SCIPgetCutoffbound())