Function SCIPupdateVarPseudocost

pub unsafe extern "C" fn SCIPupdateVarPseudocost(
    scip: *mut SCIP,
    var: *mut SCIP_VAR,
    solvaldelta: f64,
    objdelta: f64,
    weight: f64,
) -> SCIP_RETCODE
updates the pseudo costs of the given variable and the global pseudo costs after a change of “solvaldelta” in the variable’s solution value and resulting change of “objdelta” in the in the LP’s objective value; the update is ignored, if the objective value difference is infinite

@return \ref SCIP_OKAY is returned if everything worked. Otherwise a suitable error code is passed. See \ref SCIP_Retcode “SCIP_RETCODE” for a complete list of error codes.

@pre This method can be called if @p scip is in one of the following stages: - \ref SCIP_STAGE_SOLVING - \ref SCIP_STAGE_SOLVED