Function SCIPvarCompareActiveAndNegated

pub unsafe extern "C" fn SCIPvarCompareActiveAndNegated(
    var1: *mut SCIP_VAR,
    var2: *mut SCIP_VAR,
) -> c_int
compares the index of two variables, only active or negated variables are allowed, if a variable is negated then the index of the corresponding active variable is taken, returns -1 if first is smaller than, and +1 if first is greater than second variable index; returns 0 if both indices are equal, which means both variables are equal