Function SCIPvarGetBdAtIndex

pub unsafe extern "C" fn SCIPvarGetBdAtIndex(
    var: *mut SCIP_VAR,
    boundtype: SCIP_BOUNDTYPE,
    bdchgidx: *mut SCIP_BDCHGIDX,
    after: c_uint,
) -> f64
returns lower or upper bound of variable directly before or after the bound change given by the bound change index was applied

@deprecated Please use SCIPgetVarBdAtIndex()