Function SCIPvarGetLbchgInfo

pub unsafe extern "C" fn SCIPvarGetLbchgInfo(
    var: *mut SCIP_VAR,
    bdchgidx: *mut SCIP_BDCHGIDX,
    after: c_uint,
) -> *mut SCIP_BDCHGINFO
returns the bound change information for the last lower bound change on given active problem variable before or after the bound change with the given index was applied; returns NULL, if no change to the lower bound was applied up to this point of time