pub unsafe extern "C" fn SCIPvarGetNBranchingsCurrentRun(
var: *mut SCIP_VAR,
dir: SCIP_BRANCHDIR,
) -> c_longlongExpand description
returns the number of times, a bound of the variable was changed in given direction due to branching in the current run