Function SCIPvarMarkRelaxationOnly

pub unsafe extern "C" fn SCIPvarMarkRelaxationOnly(var: *mut SCIP_VAR)
marks that this variable has only been introduced to define a relaxation

The variable must not have a coefficient in the objective and must be deletable. If it is not marked deletable, it will be marked as deletable, which is only possible before the variable is added to a problem.

@see SCIPvarIsRelaxationOnly @see SCIPvarMarkDeletable