Function SCIPwasNodeLastBranchParent

pub unsafe extern "C" fn SCIPwasNodeLastBranchParent(
    scip: *mut SCIP,
    node: *mut SCIP_NODE,
) -> c_uint
query if node was the last parent of a branching of the tree

@return TRUE if node was the last parent of a branching of the tree

@pre This method can be called if SCIP is in one of the following stages: - \ref SCIP_STAGE_PRESOLVED - \ref SCIP_STAGE_SOLVING - \ref SCIP_STAGE_SOLVED