Function SCIPwriteVarsList

pub unsafe extern "C" fn SCIPwriteVarsList(
    scip: *mut SCIP,
    file: *mut FILE,
    vars: *mut *mut SCIP_VAR,
    nvars: c_int,
    type_: c_uint,
    delimiter: c_char,
) -> SCIP_RETCODE
print the given list of variables to output stream separated by the given delimiter character;

i. e. the variables x1, x2, …, xn with given delimiter ‘,’ are written as: <x1>, <x2>, …, <xn>;

the method SCIPparseVarsList() can parse such a string

@return \ref SCIP_OKAY is returned if everything worked. Otherwise a suitable error code is passed. See \ref SCIP_Retcode “SCIP_RETCODE” for a complete list of error codes.

@pre This method can be called if @p scip is in one of the following stages: - \ref SCIP_STAGE_PROBLEM - \ref SCIP_STAGE_TRANSFORMING - \ref SCIP_STAGE_TRANSFORMED - \ref SCIP_STAGE_INITPRESOLVE - \ref SCIP_STAGE_PRESOLVING - \ref SCIP_STAGE_EXITPRESOLVE - \ref SCIP_STAGE_PRESOLVED - \ref SCIP_STAGE_INITSOLVE - \ref SCIP_STAGE_SOLVING - \ref SCIP_STAGE_SOLVED - \ref SCIP_STAGE_EXITSOLVE - \ref SCIP_STAGE_FREETRANS

@note The printing process is done via the message handler system.