#[repr(C)]pub struct SCIP_AggrRow {
pub vals: *mut f64,
pub inds: *mut c_int,
pub rowsinds: *mut c_int,
pub slacksign: *mut c_int,
pub rowweights: *mut f64,
pub rhshi: f64,
pub rhslo: f64,
pub nnz: c_int,
pub nrows: c_int,
pub rowssize: c_int,
pub rank: c_int,
pub local: c_uint,
}Fields
vals: *mut f64< non-zero coefficients of the cut row
inds: *mut c_int< problem indices of variables with a non-zero coefficient in the cut row
rowsinds: *mut c_int< lpposition of rows that have been added to the cutrow
slacksign: *mut c_int< slacksign of rows that have been added to the cutrow
rowweights: *mut f64< weights of rows that have been added to the cutrow
rhshi: f64< right hand side of the cut row
rhslo: f64< right hand side of the cut row
nnz: c_int< number of non-zeros in the cut row
nrows: c_int< number of rows that have been added to the cutrow
rowssize: c_int< size of the row and slacksign array
rank: c_int< rank of the cut row
local: c_uint< is the cut row only valid locally?