Type Alias SCIP_LINCONSUPGRADE

pub type SCIP_LINCONSUPGRADE = SCIP_LinConsUpgrade;
@addtogroup CONSHDLRS

@{

@name Linear Constraints

This constraint handler handles linear constraints in their most general form. That is, \f[ lhs \leq \sum_{i=1}^n a_i x_i \leq rhs \f] with \f$a_i \in Q, i = 1,\dots,n\f$, \f$lhs\in Q \cup {-\infty}\f$, \f$rhs\in Q \cup {\infty}\f$, and decision variables \f$x_i, i = 1,\dots,n\f$ which can be binary, integer, or continuous.

Furthermore, this header offers the upgrade functionality of a general linear constraint into a more specific constraint, such as a knapsack constraint, via SCIP_DECL_LINCONSUPGD() and SCIPincludeLinconsUpgrade()

@{

Aliased Type

#[repr(C)]
pub struct SCIP_LINCONSUPGRADE { /* private fields */ }