Type Alias SCIP_NLPPARAM

pub type SCIP_NLPPARAM = SCIP_NlpParam;
parameters for NLP solve

Aliased Type

#[repr(C)]
pub struct SCIP_NLPPARAM { pub lobjlimit: f64, pub feastol: f64, pub opttol: f64, pub solvertol: f64, pub timelimit: f64, pub iterlimit: i32, pub verblevel: u16, pub fastfail: u32, pub expectinfeas: u32, pub warmstart: u32, pub caller: *const i8, }

Fields

lobjlimit: f64

< lower objective limit (cutoff)

feastol: f64

< feasibility tolerance (maximal allowed absolute violation of constraints and variable bounds)

opttol: f64

< optimality tolerance (maximal allowed absolute violation of optimality conditions)

solvertol: f64

< solver-specific tolerance on accuracy, e.g., maximal violation of feasibility and optimality in scaled problem (0.0: use solver default)

timelimit: f64

< time limit in seconds: use SCIP_REAL_MAX to use remaining time available for SCIP solve (limits/time - currenttime)

iterlimit: i32

< iteration limit

verblevel: u16

< verbosity level of output of NLP solver to the screen: 0 off, 1 normal, 2 debug, > 2 more debug

fastfail: u32

< whether the NLP solver should stop early if convergence is slow

expectinfeas: u32

< whether to expect an infeasible problem

warmstart: u32

< whether to try to use solution of previous solve as starting point (if available)

caller: *const i8

< name of file from which NLP is solved (it’s fine to set this to NULL)