Type Alias SCIP_ROWPREP

pub type SCIP_ROWPREP = SCIP_RowPrep;
a linear inequality row in preparation to become a SCIP_ROW

Used to assemble data that could eventually make a SCIP_ROW. @note Only one-sided rows are allowed here.

Aliased Type

#[repr(C)]
pub struct SCIP_ROWPREP { /* private fields */ }