pub unsafe extern "C" fn SCIPaddLinearConsIndicator(
scip: *mut SCIP,
conshdlr: *mut SCIP_CONSHDLR,
lincons: *mut SCIP_CONS,
) -> SCIP_RETCODEExpand description
adds additional linear constraint that is not connected with an indicator constraint, but can be used for separation