pub unsafe extern "C" fn SCIPboundchgIsRedundant(
boundchg: *mut SCIP_BOUNDCHG,
) -> c_uintExpand description
returns whether the bound change is redundant due to a more global bound that is at least as strong
pub unsafe extern "C" fn SCIPboundchgIsRedundant(
boundchg: *mut SCIP_BOUNDCHG,
) -> c_uintreturns whether the bound change is redundant due to a more global bound that is at least as strong