pub unsafe extern "C" fn SCIPchgAndConsCheckFlagWhenUpgr(
scip: *mut SCIP,
cons: *mut SCIP_CONS,
flag: c_uint,
) -> SCIP_RETCODEExpand description
when ‘upgrading’ the given AND-constraint, should the check flag for the upgraded constraint be set to TRUE, even if the check flag of this AND-constraint is set to FALSE?