pub unsafe extern "C" fn SCIPclearExternBranchCands(scip: *mut SCIP)Expand description
removes all external candidates from the storage for external branching
@pre This method can be called if @p scip is in one of the following stages: - \ref SCIP_STAGE_SOLVING
See \ref SCIP_Stage “SCIP_STAGE” for a complete list of all possible solving stages.