pub unsafe extern "C" fn SCIPcomputeBilinEnvelope1(
scip: *mut SCIP,
bilincoef: f64,
lbx: f64,
ubx: f64,
refpointx: f64,
lby: f64,
uby: f64,
refpointy: f64,
overestimate: c_uint,
xcoef: f64,
ycoef: f64,
constant: f64,
lincoefx: *mut f64,
lincoefy: *mut f64,
linconstant: *mut f64,
success: *mut c_uint,
)Expand description
computes coefficients of linearization of a bilinear term in a reference point when given a linear inequality involving only the variables of the bilinear term
@note the formulas are extracted from “Convex envelopes of bivariate functions through the solution of KKT systems” by Marco Locatelli