pub unsafe extern "C" fn SCIPconvertRealToLongint(
scip: *mut SCIP,
real: f64,
) -> c_longlongExpand description
converts the given real number representing an integer to a long integer; in optimized mode the function gets inlined for performance; in debug mode we check some additional conditions