pub unsafe extern "C" fn SCIPgetAvgPseudocostScore(
scip: *mut SCIP,
) -> f64Expand description
gets the average pseudo cost score value over all variables, assuming a fractionality of 0.5
@return the average pseudo cost score value over all variables, assuming a fractionality of 0.5
@pre This method can be called if SCIP is in one of the following stages: - \ref SCIP_STAGE_SOLVING - \ref SCIP_STAGE_SOLVED