pub unsafe extern "C" fn SCIPgetBestLeaf(
scip: *mut SCIP,
) -> *mut SCIP_NODEExpand description
gets the best leaf from the node queue w.r.t. the node selection strategy
@return the best leaf from the node queue w.r.t. the node selection strategy
@pre This method can be called if @p scip is in one of the following stages: - \ref SCIP_STAGE_SOLVING