pub unsafe extern "C" fn SCIPgetNBacktracks(
scip: *mut SCIP,
) -> c_longlongExpand description
gets total number of backtracks, i.e. number of times, the new node was selected from the leaves queue
@return the total number of backtracks, i.e. number of times, the new node was selected from the leaves queue
@pre This method can be called if SCIP is in one of the following stages: - \ref SCIP_STAGE_TRANSFORMED - \ref SCIP_STAGE_INITPRESOLVE - \ref SCIP_STAGE_PRESOLVING - \ref SCIP_STAGE_EXITPRESOLVE - \ref SCIP_STAGE_PRESOLVED - \ref SCIP_STAGE_INITSOLVE - \ref SCIP_STAGE_SOLVING - \ref SCIP_STAGE_SOLVED - \ref SCIP_STAGE_EXITSOLVE