pub unsafe extern "C" fn SCIPgetNPriceRounds(scip: *mut SCIP) -> c_intExpand description
gets number of pricing rounds performed so far at the current node
@return the number of pricing rounds performed so far at the current node
@pre This method can be called if SCIP is in one of the following stages: - \ref SCIP_STAGE_SOLVING