pub unsafe extern "C" fn SCIPgetVarBdAtIndex(
scip: *mut SCIP,
var: *mut SCIP_VAR,
boundtype: SCIP_BOUNDTYPE,
bdchgidx: *mut SCIP_BDCHGIDX,
after: c_uint,
) -> f64Expand description
returns lower or upper bound of variable directly before or after the bound change given by the bound change index was applied