pub unsafe extern "C" fn SCIPisCutApplicable(
scip: *mut SCIP,
cut: *mut SCIP_ROW,
) -> c_uintExpand description
indicates whether a cut is applicable
If the cut has only one variable and this method returns FALSE, it may still be possible that the cut can be added to the LP (as a row instead of a boundchange), but it will be a very weak cut. The user is asked to avoid such cuts.
@pre This method can be called if @p scip is in one of the following stages: - \ref SCIP_STAGE_SOLVING
@return whether the cut is modifiable, not a bound change, or a bound change that changes bounds by at least epsilon