pub unsafe extern "C" fn SCIPisLPRelax(scip: *mut SCIP) -> c_uintExpand description
returns whether the current lp is a relaxation of the current problem and its optimal objective value is a local lower bound
@return whether the current lp is a relaxation of the current problem and its optimal objective value is a local lower bound.
@pre This method can be called if @p scip is in one of the following stages: - \ref SCIP_STAGE_SOLVING
See \ref SCIP_Stage “SCIP_STAGE” for a complete list of all possible solving stages.