pub unsafe extern "C" fn SCIPlpiGetRealSolQuality(
lpi: *mut SCIP_LPI,
qualityindicator: SCIP_LPSOLQUALITY,
quality: *mut f64,
) -> SCIP_RETCODEExpand description
gets information about the quality of an LP solution
Such information is usually only available, if also a (maybe not optimal) solution is available. The LPI should return SCIP_INVALID for @p quality, if the requested quantity is not available.