pub unsafe extern "C" fn SCIPsetIsLbBetter(
set: *mut SCIP_SET,
newlb: f64,
oldlb: f64,
oldub: f64,
) -> c_uintExpand description
checks if the given new lower bound is at least min(oldub - oldlb, |oldlb|) times the bound strengthening epsilon better than the old one or the change in the lower bound would fix the sign of the variable