pub unsafe extern "C" fn SCIPsetSepaIsParentsepa(
scip: *mut SCIP,
sepa: *mut SCIP_SEPA,
)Expand description
declares separator to be a parent separator
Parent separators generate cuts of several types. To distinguish these cuts, they create child separators, which are only needed to detect which cuts are applied.