pub unsafe extern "C" fn SCIPvarCompActiveAndNegated(
elem1: *mut c_void,
elem2: *mut c_void,
) -> c_intExpand description
comparison method for sorting active and negated variables by non-decreasing index, active and negated variables are handled as the same variables